==> tlotd-0.3.8%20-%201.20.1-sources.jar: net/tlotd/world/biome/ModBiomes.java <==
package net.tlotd.world.biome;

import net.minecraft.class_1143;
import net.minecraft.class_1311;
import net.minecraft.class_1959;
import net.minecraft.class_2960;
import net.minecraft.class_3864;
import net.minecraft.class_4763;
import net.minecraft.class_4968;
import net.minecraft.class_5321;
import net.minecraft.class_5483;
import net.minecraft.class_5485;
import net.minecraft.class_7891;
import net.minecraft.class_7924;
import net.tlotd.TLOTD;
import net.tlotd.entity.ModEntities;

public class ModBiomes {
    public static final class_5321<class_1959> PREHISTORIC_JUNGLE = class_5321.method_29179(class_7924.field_41236,
            new class_2960(TLOTD.MOD_ID,"prehistoric_jungle")
            );
    public static final class_5321<class_1959> LUNAR_HIGHLANDS = class_5321.method_29179(class_7924.field_41236,
            new class_2960(TLOTD.MOD_ID,"lunar_highlands")
    );

    public static void bootstrap(class_7891<class_1959> context) {
        context.method_46838(PREHISTORIC_JUNGLE, prehistoricJungle(context));
        context.method_46838(LUNAR_HIGHLANDS, lunarHighlands(context));
    }

    public static void globalOverworldGeneration(class_5485.class_5495 builder) {
        class_3864.method_16983(builder);
        class_3864.method_32236(builder);
        class_3864.method_17004(builder);
        class_3864.method_17005(builder);
        class_3864.method_16996(builder);
        class_3864.method_16999(builder);
    }

    public static class_1959 prehistoricJungle(class_7891<class_1959> context) {
        class_5483.class_5496 spawnBuilder = new class_5483.class_5496();
        spawnBuilder.method_31011(class_1311.field_6294, new class_5483.class_1964(ModEntities.TREX, 2, 1, 3));

        class_3864.method_30580(spawnBuilder);
        class_3864.method_30581(spawnBuilder);

        class_5485.class_5495 biomeBuilder = new class_5485.class_5495(context.method_46799(class_7924.field_41245), context.method_46799(class_7924.field_41238));

        globalOverworldGeneration(biomeBuilder);
        class_3864.method_17012(biomeBuilder);
        class_3864.method_16959(biomeBuilder);
        class_3864.method_17010(biomeBuilder);


        //biomeBuilder.feature(GenerationStep.Feature.VEGETAL_DECORATION, VegetationPlacedFeatures.TREES_JUNGLE);

        class_3864.method_16979(biomeBuilder);
        //DefaultBiomeFeatures.addForestFlowers(biomeBuilder);
        //DefaultBiomeFeatures.addJungleGrass(biomeBuilder);

        //DefaultBiomeFeatures.addDefaultMushrooms(biomeBuilder);
        //DefaultBiomeFeatures.addDefaultVegetation(biomeBuilder);

        return new class_1959.class_1960()
                .method_48164(true)
                .method_8727(0.4f)
                .method_8747(1.2f)
                .method_30973(biomeBuilder.method_46671())
                .method_30974(spawnBuilder.method_31007())
                .method_24379((new class_4763.class_4764())
                        .method_24395(0x00BA95)
                        .method_24397(0x00BA95)
                        .method_30822(0x558A2B)
                        .method_30821(0x558A2B)
                        .method_24392(0xCCCCFF)
                        .method_30820(0xCCCCFF)
                        .method_24943(class_4968.field_23146)
                        .method_27346(class_1143.field_5586)
                        .method_24391()
                ).method_30972();
    }

    public static class_1959 lunarHighlands(class_7891<class_1959> context) {

        class_5483.class_5496 spawnBuilder = new class_5483.class_5496();

        class_5485.class_5495 biomeBuilder = new class_5485.class_5495(context.method_46799(class_7924.field_41245), context.method_46799(class_7924.field_41238));

        class_3864.method_16983(biomeBuilder);
        class_3864.method_17005(biomeBuilder);

        return new class_1959.class_1960()
                .method_48164(false)
                .method_8727(0.0f)
                .method_8747(0.5f)
                .method_30973(biomeBuilder.method_46671())
                .method_30974(spawnBuilder.method_31007())
                .method_24379((new class_4763.class_4764())
                        .method_24395(0x526675)
                        .method_24397(0x526675)
                        .method_30822(0x577552)
                        .method_30821(0x577552)
                        .method_24392(0x000000)
                        .method_30820(0x000000)
                        .method_24943(class_4968.field_23146)
                        .method_27346(class_1143.field_5586)
                        .method_24391()
                ).method_30972();
    }
}

==> tlotd-0.3.9%20-%201.20.1-sources.jar: net/tlotd/world/biome/ModBiomes.java <==
package net.tlotd.world.biome;

import net.minecraft.class_1143;
import net.minecraft.class_1311;
import net.minecraft.class_1959;
import net.minecraft.class_2893;
import net.minecraft.class_2960;
import net.minecraft.class_3864;
import net.minecraft.class_4763;
import net.minecraft.class_4968;
import net.minecraft.class_5321;
import net.minecraft.class_5483;
import net.minecraft.class_5485;
import net.minecraft.class_7891;
import net.minecraft.class_7924;
import net.tlotd.TLOTD;
import net.tlotd.entity.ModEntities;
import net.tlotd.world.ModPlacedFeatures;

public class ModBiomes {
    public static final class_5321<class_1959> PREHISTORIC_JUNGLE = class_5321.method_29179(class_7924.field_41236,
            new class_2960(TLOTD.MOD_ID,"prehistoric_jungle")
            );
    public static final class_5321<class_1959> LUNAR_HIGHLANDS = class_5321.method_29179(class_7924.field_41236,
            new class_2960(TLOTD.MOD_ID,"lunar_highlands")
    );

    public static void bootstrap(class_7891<class_1959> context) {
        context.method_46838(PREHISTORIC_JUNGLE, prehistoricJungle(context));
        context.method_46838(LUNAR_HIGHLANDS, lunarHighlands(context));
    }

    public static void globalOverworldGeneration(class_5485.class_5495 builder) {
        class_3864.method_16983(builder);
        class_3864.method_32236(builder);
        class_3864.method_17004(builder);
        class_3864.method_17005(builder);
        class_3864.method_16996(builder);
        class_3864.method_16999(builder);
    }

    public static class_1959 prehistoricJungle(class_7891<class_1959> context) {
        class_5483.class_5496 spawnBuilder = new class_5483.class_5496();
        spawnBuilder.method_31011(class_1311.field_6294, new class_5483.class_1964(ModEntities.TREX, 2, 1, 3));

        class_3864.method_30580(spawnBuilder);
        class_3864.method_30581(spawnBuilder);

        class_5485.class_5495 biomeBuilder = new class_5485.class_5495(context.method_46799(class_7924.field_41245), context.method_46799(class_7924.field_41238));

        globalOverworldGeneration(biomeBuilder);
        class_3864.method_17012(biomeBuilder);

        biomeBuilder.method_30992(
                class_2893.class_2895.field_13178,
                ModPlacedFeatures.MEGA_GINKGO_TREE_PLACED_KEY
        );
        biomeBuilder.method_30992(
                class_2893.class_2895.field_13178,
                ModPlacedFeatures.GINKGO_TREE_PLACED_KEY
        );
        class_3864.method_16959(biomeBuilder);
        class_3864.method_17010(biomeBuilder);
        class_3864.method_16979(biomeBuilder);
        class_3864.method_16965(biomeBuilder);
        class_3864.method_16982(biomeBuilder);

        return new class_1959.class_1960()
                .method_48164(true)
                .method_8727(0.4f)
                .method_8747(1.2f)
                .method_30973(biomeBuilder.method_46671())
                .method_30974(spawnBuilder.method_31007())
                .method_24379((new class_4763.class_4764())
                        .method_24395(0x00BA95)
                        .method_24397(0x00BA95)
                        .method_30822(0x558A2B)
                        .method_30821(0x558A2B)
                        .method_24392(0xCCCCFF)
                        .method_30820(0xCCCCFF)
                        .method_24943(class_4968.field_23146)
                        .method_27346(class_1143.field_5586)
                        .method_24391()
                ).method_30972();
    }

    public static class_1959 lunarHighlands(class_7891<class_1959> context) {

        class_5483.class_5496 spawnBuilder = new class_5483.class_5496();

        class_5485.class_5495 biomeBuilder = new class_5485.class_5495(context.method_46799(class_7924.field_41245), context.method_46799(class_7924.field_41238));

        class_3864.method_16983(biomeBuilder);
        class_3864.method_17005(biomeBuilder);

        return new class_1959.class_1960()
                .method_48164(false)
                .method_8727(0.0f)
                .method_8747(0.5f)
                .method_30973(biomeBuilder.method_46671())
                .method_30974(spawnBuilder.method_31007())
                .method_24379((new class_4763.class_4764())
                        .method_24395(0x526675)
                        .method_24397(0x526675)
                        .method_30822(0x577552)
                        .method_30821(0x577552)
                        .method_24392(0x000000)
                        .method_30820(0x000000)
                        .method_24943(class_4968.field_23146)
                        .method_27346(class_1143.field_5586)
                        .method_24391()
                ).method_30972();
    }
}
